==> HSAUR2_1.0-1.tar.gz: HSAUR2/tests/preface.R <==
###################################################
### chunk number 1: setup
###################################################
rm(list = ls())
if (!file.exists("tables")) dir.create("tables")
set.seed(290875)
options(prompt = "R> ", continue = "+  ",
    width = 63, # digits = 4,
    show.signif.stars = FALSE,
    SweaveHooks = list(leftpar = function()
        par(mai = par("mai") * c(1, 1.05, 1, 1)),
        bigleftpar = function()
        par(mai = par("mai") * c(1, 1.7, 1, 1))))
HSAURpkg <- require("HSAUR2")
if (!HSAURpkg) stop("cannot load package ", sQuote("HSAUR2"))
rm(HSAURpkg)
 ### </FIXME> hm, R-2.4.0 --vanilla seems to need this
a <- Sys.setlocale("LC_ALL", "C")
 ### </FIXME>
book <- TRUE
refs <- cbind(c("AItR", "DAGD", "SI", "CI", "ANOVA", "MLR", "GLM",
                "DE", "RP", "GAM", "SA", "ALDI", "ALDII", "SIMC", "MA", "PCA",
                "MDS", "CA"), 1:18)
ch <- function(x) {
    ch <- refs[which(refs[,1] == x),]
    if (book) {
        return(paste("Chapter~\\\\ref{", ch[1], "}", sep = ""))
    } else {
        return(paste("Chapter~", ch[2], sep = ""))
    }
}
if (file.exists("deparse.R"))
    source("deparse.R")
setHook(packageEvent("lattice", "attach"), function(...) {
    lattice.options(default.theme =
        function()
            standard.theme("pdf", color = FALSE))
    })


###################################################
### chunk number 2: pre-HSAUR-install eval=FALSE
###################################################
## install.packages("HSAUR")


###################################################
### chunk number 3: pre-HSAUR eval=FALSE
###################################################
## library("HSAUR")


###################################################
### chunk number 4: pre-vignette eval=FALSE
###################################################
## vignette("Ch_introduction_to_R", package = "HSAUR")


###################################################
### chunk number 5: pre-vignette-source eval=FALSE
###################################################
## edit(vignette("Ch_introduction_to_R", package = "HSAUR"))


###################################################
### chunk number 6: pre-vignette-source eval=FALSE
###################################################
## vignette(package = "HSAUR")

==> HSAUR2_1.0-4.tar.gz: HSAUR2/tests/preface.R <==
###################################################
### chunk number 1: setup
###################################################
#line 181 "preface.Rnw"
rm(list = ls())
if (!file.exists("tables")) dir.create("tables")
if (!file.exists("figures")) dir.create("figures")
set.seed(290875)
options(prompt = "R> ", continue = "+  ",
    width = 63, # digits = 4,
    show.signif.stars = FALSE,
    SweaveHooks = list(leftpar = function()
        par(mai = par("mai") * c(1, 1.05, 1, 1)),
        bigleftpar = function()
        par(mai = par("mai") * c(1, 1.7, 1, 1))))
HSAURpkg <- require("HSAUR2")
if (!HSAURpkg) stop("cannot load package ", sQuote("HSAUR2"))
rm(HSAURpkg)
 ### </FIXME> hm, R-2.4.0 --vanilla seems to need this
a <- Sys.setlocale("LC_ALL", "C")
 ### </FIXME>
book <- TRUE
refs <- cbind(c("AItR", "DAGD", "SI", "CI", "ANOVA", "MLR", "GLM",
                "DE", "RP", "GAM", "SA", "ALDI", "ALDII", "SIMC", "MA", "PCA",
                "MDS", "CA"), 1:18)
ch <- function(x) {
    ch <- refs[which(refs[,1] == x),]
    if (book) {
        return(paste("Chapter~\\\\ref{", ch[1], "}", sep = ""))
    } else {
        return(paste("Chapter~", ch[2], sep = ""))
    }
}
if (file.exists("deparse.R"))
    source("deparse.R")
setHook(packageEvent("lattice", "attach"), function(...) {
    lattice.options(default.theme =
        function()
            standard.theme("pdf", color = FALSE))
    })


###################################################
### chunk number 2: pre-HSAUR-install eval=FALSE
###################################################
## #line 260 "preface.Rnw"
## install.packages("HSAUR")


###################################################
### chunk number 3: pre-HSAUR eval=FALSE
###################################################
## #line 264 "preface.Rnw"
## library("HSAUR")


###################################################
### chunk number 4: pre-vignette eval=FALSE
###################################################
## #line 271 "preface.Rnw"
## vignette("Ch_introduction_to_R", package = "HSAUR")


###################################################
### chunk number 5: pre-vignette-source eval=FALSE
###################################################
## #line 275 "preface.Rnw"
## edit(vignette("Ch_introduction_to_R", package = "HSAUR"))


###################################################
### chunk number 6: pre-vignette-source eval=FALSE
###################################################
## #line 280 "preface.Rnw"
## vignette(package = "HSAUR")
